<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Support\Facades\Auth;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = '/';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest')->except('logout');
    }

    public function login()
    {
        require_once(env('SSP_PATH'));

        $ssp = new \SimpleSAML_Auth_Simple(env('SSP_ENVIRONMENT'));
        $ssp->requireAuth();
        $attributes = $ssp->getAttributes();

        if ( ! isset($attributes['hrEduPersonUniqueID'])) {
            return redirect()->route('home')->withErrors([
                'Greška! Nije moguće dohvatiti AAI korisničke podatke.'
            ]);
        }

        $uid = $attributes['hrEduPersonUniqueID'][0];
        #$uid = 'hsute@srce.hr';
        $user = User::where('uid', $uid)->first();

        if(!$user) {
            return redirect()->route('home')->withErrors([
                'Nemate pravo pristupa aplikaciji.'
            ]);
        }
        Auth::login($user);

        return redirect()->intended('/');
    }

    public function logout()
    {
        require_once(env('SSP_PATH'));

        $ssp = new \SimpleSAML_Auth_Simple(env('SSP_ENVIRONMENT'));

        if( $ssp->isAuthenticated() ) {
            $ssp->logout();
        }

        Auth::logout();
        return redirect()->home();
    }

}
