<?php

namespace App\Http\Controllers;

use App\Http\Requests\AbuseLIPRequest;
use App\Http\Requests\AbuseSearchRequest;
use App\Http\Requests\RadiusSwitchRequest;
use App\Http\Requests\MacRequest;
use App\Http\Requests\StatRequest;
use App\Http\Requests\UserUqidRequest;
use App\Repositories\AcctLogQuery;
use App\Repositories\UlogQuery;
use Illuminate\Http\Request;
use Kris\LaravelFormBuilder\FormBuilder;

\Carbon\Carbon::setToStringFormat('d.m.Y H.m.s');

class StudomController extends Controller
{
    public function index(){
        session(['menu' => null]);
        return view('home', ['pageTitle' => 'StuDOM AAI nadzor']);
    }

    public function statIndex(FormBuilder $formBuilder){
        session(['menu' => 'stat']);
        $formMacTotal = $formBuilder->create(\App\Forms\StatMACTotalForm::class, [
            'method' => 'POST',
            'url' => route('stat_mac_tot_query')
        ]);
        $formMac = $formBuilder->create(\App\Forms\StatMACForm::class, [
            'method' => 'POST',
            'url' => route('stat_mac_query')
        ]);
        $formUserTotal = $formBuilder->create(\App\Forms\StatUserTotalForm::class, [
            'method' => 'POST',
            'url' => route('stat_user_tot_query')
        ]);
        $formUser = $formBuilder->create(\App\Forms\StatUserForm::class, [
            'method' => 'POST',
            'url' => route('stat_user_query')
        ]);


        return view('stat.forms', ['pageTitle' => 'Statistika', 'formMacTotal' => $formMacTotal, 'formMac' => $formMac,
            'formUserTotal' => $formUserTotal, 'formUser' => $formUser]);
    }

    public function abuseIndex(FormBuilder $formBuilder){
        session(['menu' => 'abuse']);
        $form = $formBuilder->create(\App\Forms\AbuseForm::class, [
            'method' => 'GET',
            'url' => route('abuse_query')
        ]);
        $formLIP = $formBuilder->create(\App\Forms\AbuseLocalIPForm::class, [
            'method' => 'GET',
            'url' => route('lip_abuse_query')
        ]);

        return view('abuse.forms', ['pageTitle' => 'Abuse', 'form' => $form, 'formLIP' => $formLIP]);
    }

    public function radiusIndex(FormBuilder $formBuilder){
        session(['menu' => 'radius']);
        $formTotal = $formBuilder->create(\App\Forms\RadiusSwitchTotalForm::class, [
            'method' => 'POST',
            'url' => route('radius_switch_tot_query')
        ]);

        return view('radius.forms', ['pageTitle' => 'Statistike korištenja mrežnih resursa', 'formTotal' => $formTotal]);
    }

    public function userIndex(FormBuilder $formBuilder){
        session(['menu' => 'user']);
        $form = $formBuilder->create(\App\Forms\UserForm::class, [
            'method' => 'POST',
            'url' => route('user_query')
        ]);
        $formMac = $formBuilder->create(\App\Forms\UserMacForm::class, [
            'method' => 'POST',
            'url' => route('user_mac_query')
        ]);

        return view('users.forms', ['pageTitle' => 'Korisnici', 'form' => $form, 'formMac' => $formMac]);
    }

    public function statMacTotalQuery(AcctLogQuery $acctLogQuery, StatRequest $request){
        return view('stat.mac_total', ['pageTitle' => 'Statistika', 'datumFrom' => $acctLogQuery->input['date_from'],
            'datumTo' => $acctLogQuery->input['date_to'], 'results' => $acctLogQuery->getMacTotal()]);
    }

    public function statMacQuery(AcctLogQuery $acctLogQuery, MacRequest $request){
        return view('stat.mac', ['pageTitle' => 'Statistika', 'datumFrom' => $acctLogQuery->input['date_from'],
            'datumTo' => $acctLogQuery->input['date_to'], 'mac' => $acctLogQuery->input['mac'], 'results' => $acctLogQuery->getMacQuery()]);
    }

    public function statUserTotalQuery(AcctLogQuery $acctLogQuery, StatRequest $request){
        return view('stat.users_total', ['pageTitle' => 'Statistika', 'datumFrom' => $acctLogQuery->input['date_from'],
            'datumTo' => $acctLogQuery->input['date_to'], 'results' => $acctLogQuery->getUsersTotalStat()]);
    }

    public function statUserQuery(AcctLogQuery $acctLogQuery, UserUqidRequest $request){
        return view('stat.user', ['pageTitle' => 'Statistika', 'datumFrom' => $acctLogQuery->input['date_from'],
            'datumTo' => $acctLogQuery->input['date_to'], 'uqid' => $acctLogQuery->input['uqid'], 'results' => $acctLogQuery->getUserStat()]);
    }

    public function userMacQuery(AcctLogQuery $acctLogQuery, MacRequest $request){
        return view('users.mac', ['pageTitle' => 'Korisnici', 'date_from' => $acctLogQuery->input['date_from'], 'date_to' => $acctLogQuery->input['date_to'],
            'mac' => $acctLogQuery->input['mac'], 'results' => $acctLogQuery->getUsersMacQuery()]);
    }

    public function userQuery(AcctLogQuery $acctLogQuery, UserUqidRequest $request){
        return view('users.uqid', ['pageTitle' => 'Korisnici', 'date_from' => $acctLogQuery->input['date_from'], 'date_to' => $acctLogQuery->input['date_to'],
            'uqid' => $acctLogQuery->input['uqid'], 'results' => $acctLogQuery->getUsersQuery()]);
    }

    public function abuseQuery(UlogQuery $abuse, AbuseSearchRequest $request)
    {
        $results = $abuse->search();
        $both = ['time_from' => $abuse->getInputField('time_from'), 'time_to' => $abuse->getInputField('time_to'), 'destination_ip' => $abuse->getInputField('destination_ip')];
        $results->appends(['datum' => $abuse->getInputField('datum'), 'port' => $abuse->getInputField('port'), 'port_type' => $abuse->getInputField('port_type')] + $both);

        return view('abuse.search', ['pageTitle' => 'Abuse', 'results' => $results] + $both);
    }

    public function abuseSearchUser(AcctLogQuery $acctLogQuery)
    {
        return view('abuse.user', ['pageTitle' => 'Abuse', 'mac' => $acctLogQuery->input['raw_mac'], 'logTime' => $acctLogQuery->input['log_time'],
            'results' => $acctLogQuery->findUser()]);
    }

    public function abuselocalIPQuery(UlogQuery $abuse, AbuseLIPRequest $request)
    {
        $results = $abuse->searchLIP();
        $both = ['time_from' => $abuse->getInputField('time_from'), 'time_to' => $abuse->getInputField('time_to'), 'source_ip' => $abuse->getInputField('source_ip')];
        $results->appends(['datum' => $abuse->getInputField('datum')] + $both);

        return view('abuse.search_lip', ['pageTitle' => 'Abuse', 'results' => $results] + $both);
    }

    public function radiusSwitchTotalQuery(AcctLogQuery $acctLogQuery, RadiusSwitchRequest $request)
    {
        return view('radius.switch_total', ['pageTitle' => 'Statistike korištenja mrežnih resursa', 'datumFrom' => $acctLogQuery->input['datum_from_switch_total'],
            'datumTo' => $acctLogQuery->input['datum_to_switch_total'], 'results' => $acctLogQuery->getTotalSwitchTraffic()]);
    }

    public function radiusSwitchStat(AcctLogQuery $acctLogQuery)
    {
        return view('radius.switch', ['pageTitle' => 'Statistike korištenja mrežnih resursa', 'datumFrom' => $acctLogQuery->input['date_from'],
            'datumTo' => $acctLogQuery->input['date_to'], 'switchIP' => $acctLogQuery->input['nas_ip'], 'results' => $acctLogQuery->getSwitchStats()]);
    }

    public function radiusSwitchQuery(){
        dd(request()->input());
    }
}
